AutoFunctionDeclaration class final

A FunctionDeclaration for auto function calling.

Inheritance

Constructors

AutoFunctionDeclaration({required String name, required String description, required Map<String, Schema> parameters, List<String> optionalParameters = const [], required FutureOr<Map<String, Object?>> callable(Map<String, Object?> args)})
Creates an AutoFunctionDeclaration.

Properties

callable FutureOr<Map<String, Object?>> Function(Map<String, Object?> args)
The callable function that this declaration represents.
final
description String
A brief description of the function.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the function.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to json object.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited