CodeExecutionResultPart class final

A Part that represents the code execution result from the model.

Inheritance

Constructors

CodeExecutionResultPart({required Outcome outcome, required String output, bool? isThought})

Properties

hashCode int
The hash code for this object.
no setterinherited
isThought bool?
finalinherited
outcome → Outcome
The result of the execution.
final
output String
The stdout from the code execution, or an error message if it failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Convert the Part content to json format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited