CountTokensResponse class final

Response for Count Tokens

Constructors

CountTokensResponse(int totalTokens, {int? totalBillableCharacters, List<ModalityTokenCount>? promptTokensDetails})

Properties

hashCode int
The hash code for this object.
no setterinherited
promptTokensDetails List<ModalityTokenCount>?
List of modalities that were processed in the request input.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBillableCharacters int?
The number of characters that the model could bill at.
final
totalTokens int
The number of tokens that the model tokenizes the prompt into.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited