promptTokensDetails property
List of modalities that were processed in the request input.
Implementation
final List<ModalityTokenCount>? promptTokensDetails;
List of modalities that were processed in the request input.
final List<ModalityTokenCount>? promptTokensDetails;