totalBillableCharacters property

  1. @Deprecated('Use `totalTokens` instead; Gemini 2.0 series models and newer are always billed by token count.')
int? totalBillableCharacters
final

The number of characters that the model could bill at.

Always non-negative.

Implementation

@Deprecated(
  'Use `totalTokens` instead; Gemini 2.0 series models and newer are always billed by token count.',
)
final int? totalBillableCharacters;