FileData class final

A Part with Firebase Storage uri as prompt content

Inheritance

Constructors

FileData(String mimeType, String fileUri, {bool? isThought})
const
FileData.forTest(String mimeType, String fileUri, {bool? isThought, String? thoughtSignature})
const

Properties

fileUri String
The gs link for Firebase Storage reference
final
hashCode int
The hash code for this object.
no setterinherited
isThought bool?
finalinherited
mimeType String
File type of the FileData. https://cloud.google.com/vertex-ai/generative-ai/docs/multimodal/send-multimodal-prompts#media_requirements
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Convert the Part content to json format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited