FirebaseAISdkException class final

Exception indicating a stale package version or implementation bug.

This exception indicates a likely problem with the SDK implementation such as an inability to parse a new response format. Resolution paths may include updating to a new version of the SDK, or filing an issue.

Implemented types

Constructors

FirebaseAISdkException(String message)

Properties

hashCode int
The hash code for this object.
no setterinherited
message String
Message of the exception
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited