FunctionCall class final

A predicted FunctionCall returned from the model that contains a string representing the FunctionDeclaration.name with the arguments and their values.

Inheritance

Constructors

FunctionCall(String name, Map<String, Object?> args, {String? id, bool? isThought})
const
FunctionCall.forTest(String name, Map<String, Object?> args, {String? id, bool? isThought, String? thoughtSignature})
const

Properties

args Map<String, Object?>
The function parameters and values.
final
hashCode int
The hash code for this object.
no setterinherited
id String?
The unique id of the function call.
final
isThought bool?
finalinherited
name String
The name of the function to call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Convert the Part content to json format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited