allowedFunctionNames property

Set<String>? allowedFunctionNames
final

A set of function names that, when provided, limits the functions the model will call.

This should only be set when the Mode is FunctionCallingMode.any. Function names should match FunctionDeclaration.name. With mode set to any, model will predict a function call from the set of function names provided.

Implementation

final Set<String>? allowedFunctionNames;