FunctionDeclaration class

Structured representation of a function declaration as defined by the OpenAPI 3.03 specification.

Included in this declaration are the function name and parameters. This FunctionDeclaration is a representation of a block of code that can be used as a Tool by the model and executed by the client.

Implementers

Constructors

FunctionDeclaration(String name, String description, {required Map<String, Schema> parameters, List<String> optionalParameters = const []})

Properties

description String
A brief description of the function.
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the function.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to json object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited