GoingAwayNotice class

A server message indicating that the server will not be able to service the client soon.

Implemented types

Constructors

GoingAwayNotice({String? timeLeft})
Creates a GoingAwayNotice instance.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timeLeft String?
The remaining time before the connection will be terminated as ABORTED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited