HarmProbability enum
The probability that a piece of content is harmful.
The classification system gives the probability of the content being unsafe. This does not indicate the severity of harm for a piece of content.
Values
- unknown → const HarmProbability
-
A new and not yet supported value.
const HarmProbability('UNKNOWN') - negligible → const HarmProbability
-
Content has a negligible probability of being unsafe.
const HarmProbability('NEGLIGIBLE') - low → const HarmProbability
-
Content has a low probability of being unsafe.
const HarmProbability('LOW') - medium → const HarmProbability
-
Content has a medium probability of being unsafe.
const HarmProbability('MEDIUM') - high → const HarmProbability
-
Content has a high probability of being unsafe.
const HarmProbability('HIGH')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Convert to json format.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
HarmProbability> - A constant List of the values in this enum, in order of their declaration.