ImageSize enum

The size of images to generate.

Inheritance
Available extensions

Values

size512 → const ImageSize

512px (0.5K) image size.

const ImageSize('512')
size1K → const ImageSize

1K image size.

const ImageSize('1K')
size2K → const ImageSize

2K image size.

const ImageSize('2K')
size4K → const ImageSize

4K image size.

const ImageSize('4K')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
Convert to json format.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImageSize>
A constant List of the values in this enum, in order of their declaration.