ImagenDimensions class final

The dimensions of an image.

Annotations
  • @experimental
  • @Deprecated('All Imagen models are deprecated and will shut down as early as June 2026. ' 'As a replacement, you can migrate your apps to use Gemini Image models (the ' '"Nano Banana" models)(https://firebase.google.com/docs/ai-logic/imagen-models-migration).')

Constructors

ImagenDimensions({required int width, required int height})

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
The height of the image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int
The width of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited