ImagenEditMode enum

The desired outcome of the image editing.

Inheritance
Available extensions
Annotations
  • @experimental

Values

inpaintInsertion → const ImagenEditMode

The result of the editing will be an insertion of the prompt in the masked region.

const ImagenEditMode('EDIT_MODE_INPAINT_INSERTION')
inpaintRemoval → const ImagenEditMode

The result of the editing will be a removal of the masked region.

const ImagenEditMode('EDIT_MODE_INPAINT_REMOVAL')
outpaint → const ImagenEditMode

The result of the editing will be an outpainting of the source image.

const ImagenEditMode('EDIT_MODE_OUTPAINT')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImagenEditMode>
A constant List of the values in this enum, in order of their declaration.