ImagenEditingConfig class final
The configuration for image editing.
- Annotations
-
- @experimental
Constructors
- ImagenEditingConfig({ImagenEditMode? editMode, int? editSteps})
Properties
- editMode → ImagenEditMode?
-
The mode of the editing.
final
- editSteps → int?
-
The number of steps for the editing.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited