ImagenMaskConfig class final

The configuration for the mask.

Annotations
  • @experimental
  • @Deprecated('All Imagen models are deprecated and will shut down as early as June 2026. ' 'As a replacement, you can migrate your apps to use Gemini Image models (the ' '"Nano Banana" models)(https://firebase.google.com/docs/ai-logic/imagen-models-migration).')

Constructors

ImagenMaskConfig({required ImagenMaskMode maskMode, double? maskDilation, List<int>? maskClasses})

Properties

hashCode int
The hash code for this object.
no setterinherited
maskClasses List<int>?
The classes of the mask.
final
maskDilation double?
The dilation of the mask.
final
maskMode ImagenMaskMode
The type of the mask.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert the ImagenReferenceConfig content to json format.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited