ImagenMaskMode enum

The mode of the mask.

Inheritance
Available extensions
Annotations
  • @experimental

Values

userProvided → const ImagenMaskMode

The mask is user provided.

const ImagenMaskMode('MASK_MODE_USER_PROVIDED')
background → const ImagenMaskMode

The mask is the background.

const ImagenMaskMode('MASK_MODE_BACKGROUND')
foreground → const ImagenMaskMode

The mask is the foreground.

const ImagenMaskMode('MASK_MODE_FOREGROUND')
semantic → const ImagenMaskMode

The mask is semantic.

const ImagenMaskMode('MASK_MODE_SEMANTIC')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ImagenMaskMode>
A constant List of the values in this enum, in order of their declaration.