ImagenModel class final
Represents a remote Imagen model with the ability to generate images using text prompts.
See the Cloud documentation for more details about the image generation capabilities offered by the Imagen model.
Warning: For Vertex AI in Firebase, image generation using Imagen 3 models is in Public Preview, which means that the feature is not subject to any SLA or deprecation policy and could change in backwards-incompatible ways.
Properties
Methods
-
editImage(
List< ImagenReferenceImage> referenceImages, String prompt, {ImagenEditingConfig? config}) → Future<ImagenGenerationResponse< ImagenInlineImage> > - Edits an image based on a prompt and a list of reference images.
-
generateImages(
String prompt) → Future< ImagenGenerationResponse< ImagenInlineImage> > - Generates images with format of ImagenInlineImage based on the given prompt.
-
inpaintImage(
ImagenInlineImage image, String prompt, ImagenMaskReference mask, {ImagenEditingConfig? config}) → Future< ImagenGenerationResponse< ImagenInlineImage> > - Inpaints an image based on a prompt and a mask.
-
makeRequest<
T> (Task task, Map< String, Object?> params, T parse(Map<String, Object?> )) → Future<T> -
Make a unary request for
taskwith JSON encodableparams.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
taskUri(
Task task) → Uri -
Returns a URI for the given
task.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited