ImagenStyleReference class final

A style reference.

Inheritance
Annotations
  • @experimental

Constructors

ImagenStyleReference({required ImagenInlineImage image, String? description, required int? referenceId})

Properties

hashCode int
The hash code for this object.
no setterinherited
image ImagenInlineImage?
The actual image data of the reference image.
finalinherited
referenceConfig → ImagenReferenceConfig?
A config describing the reference image.
finalinherited
referenceId int?
The reference ID of the image.
finalinherited
referenceType → _ReferenceType
The type of the reference image.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson({int referenceIdOverrideIfNull = 0}) Map<String, Object?>
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited