items property
JSONSchema for the elements if this is a SchemaType.array.
Implementation
@override
JSONSchema? get items => super.items as JSONSchema?;
Schema for the elements if this is a SchemaType.array.
Implementation
@override
set items(covariant JSONSchema? value) => super.items = value;