properties property

  1. @override
Map<String, JSONSchema>? get properties
override

Properties of this type if this is a SchemaType.object.

Implementation

@override
Map<String, JSONSchema>? get properties =>
    super.properties as Map<String, JSONSchema>?;
  1. @override
set properties (covariant Map<String, JSONSchema>? value)
covariantoverride

Properties of this type if this is a SchemaType.object.

Implementation

@override
set properties(covariant Map<String, JSONSchema>? value) =>
    super.properties = value;