LiveServerContent class

Content generated by the model in a live stream.

Implemented types

Constructors

LiveServerContent({Content? modelTurn, bool? turnComplete, bool? interrupted, Transcription? inputTranscription, Transcription? outputTranscription})
Creates a LiveServerContent instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
inputTranscription Transcription?
The input transcription.
final
interrupted bool?
Whether generation was interrupted. If true, indicates that a client message has interrupted current model
final
modelTurn Content?
The content generated by the model.
final
outputTranscription Transcription?
The output transcription.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
turnComplete bool?
Whether the turn is complete. If true, indicates that the model is done generating.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited