interrupted property
Whether generation was interrupted. If true, indicates that a client message has interrupted current model
Implementation
final bool? interrupted;
Whether generation was interrupted. If true, indicates that a client message has interrupted current model
final bool? interrupted;