outputTranscription property
The output transcription.
The transcription is independent to the model turn which means it doesn't imply any ordering between transcription and model turn.
Implementation
final Transcription? outputTranscription;
The output transcription.
The transcription is independent to the model turn which means it doesn't imply any ordering between transcription and model turn.
final Transcription? outputTranscription;