turnComplete property
Whether the turn is complete. If true, indicates that the model is done generating.
Implementation
final bool? turnComplete;
Whether the turn is complete. If true, indicates that the model is done generating.
final bool? turnComplete;