LiveServerResponse class

A single response chunk received during a live content generation.

It can contain generated content, function calls to be executed, or instructions to cancel previous function calls, along with the status of the ongoing generation.

Constructors

LiveServerResponse({required LiveServerMessage message})

Properties

hashCode int
The hash code for this object.
no setterinherited
message LiveServerMessage
The server message generated by the live model.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited