MediaResolution enum

The media resolution to use for media inputs.

Inheritance
Available extensions

Values

unspecified → const MediaResolution

Default media resolution selected by the model.

const MediaResolution('MEDIA_RESOLUTION_UNSPECIFIED')
low → const MediaResolution

Lower token count, resulting in faster processing and lower cost.

const MediaResolution('MEDIA_RESOLUTION_LOW')
medium → const MediaResolution

A balance between detail, cost, and latency.

const MediaResolution('MEDIA_RESOLUTION_MEDIUM')
high → const MediaResolution

Higher token count, providing more detail for media inputs.

const MediaResolution('MEDIA_RESOLUTION_HIGH')
ultraHigh → const MediaResolution

Highest token count for image inputs.

This value is only supported on individual media parts.

const MediaResolution('MEDIA_RESOLUTION_ULTRA_HIGH')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parseValue(String value) MediaResolution
Parse a media resolution from a JSON value.

Constants

values → const List<MediaResolution>
A constant List of the values in this enum, in order of their declaration.