PromptFeedback class final

Feedback metadata of a prompt specified in a GenerativeModel request.

Constructors

PromptFeedback(BlockReason? blockReason, String? blockReasonMessage, List<SafetyRating> safetyRatings)

Properties

blockReason BlockReason?
If set, the prompt was blocked and no candidates are returned.
final
blockReasonMessage String?
Message for the block reason.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
safetyRatings List<SafetyRating>
Ratings for safety of the prompt.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited