RetrievalConfig class final

The configuration that specifies information which can be used by tools during inference calls.

Constructors

RetrievalConfig({LatLng? latLng, String? languageCode})

Properties

hashCode int
The hash code for this object.
no setterinherited
languageCode String?
The language code.
final
latLng LatLng?
A latitude/longitude pair.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to json object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited