SessionResumptionConfig class

Configuration for the session resumption mechanism.

When included in the session setup, the server will send SessionResumptionUpdate messages.

Constructors

SessionResumptionConfig()
Creates a SessionResumptionConfig to start a new resumable session.
SessionResumptionConfig.resume(String handle)
Creates a SessionResumptionConfig to resume a previous session.

Properties

handle String?
The session resumption handle of the previous session to restore.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited