handle property
The session resumption handle of the previous session to restore.
If null, a new session will be started (and will be resumable if this config was included).
Implementation
final String? handle;
The session resumption handle of the previous session to restore.
If null, a new session will be started (and will be resumable if this config was included).
final String? handle;