SessionResumptionUpdate constructor

SessionResumptionUpdate({
  1. String? newHandle,
  2. bool? resumable,
  3. int? lastConsumedClientMessageIndex,
})

Creates a SessionResumptionUpdate instance.

newHandle (optional): The new handle that represents the state that can be resumed. resumable (optional): Indicates if the session can be resumed at this point. lastConsumedClientMessageIndex (optional): The index of the last client message that is included in the state represented by this update.

Implementation

SessionResumptionUpdate(
    {this.newHandle, this.resumable, this.lastConsumedClientMessageIndex});