lastConsumedClientMessageIndex property

int? lastConsumedClientMessageIndex
final

The index of the last client message that is included in the state represented by this update.

Implementation

final int? lastConsumedClientMessageIndex;