newHandle property
The new handle that represents the state that can be resumed. Empty if
resumable is false.
Implementation
final String? newHandle;
The new handle that represents the state that can be resumed. Empty if
resumable is false.
final String? newHandle;