SlidingWindow class

Configures the sliding window context compression mechanism.

The SlidingWindow method operates by discarding content at the beginning of the context window. The resulting context will always begin at the start of a USER role turn. System instructions will always remain at the start of the result.

Constructors

SlidingWindow({int? targetTokens})
Creates a SlidingWindow instance.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetTokens int?
The session reduction target, i.e., how many tokens we should keep.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited