TemplateFunctionDeclaration class

A function declaration for a template tool.

Implementers

Constructors

TemplateFunctionDeclaration(String name, {Map<String, JSONSchema>? parameters, List<String> optionalParameters = const []})

Properties

hashCode int
The hash code for this object.
no setterinherited
hasSchema bool
Whether the function declaration has a schema override.
no setter
name String
The name of the function.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to json object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited