TextPart class final

A Part with the text content.

Inheritance

Constructors

TextPart(String text, {bool? isThought})
const
TextPart.forTest(String text, {bool? isThought, String? thoughtSignature})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isThought bool?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The text content of the Part
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Object
Convert the Part content to json format.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited