thinkingBudget property

int? thinkingBudget
final

The number of thoughts tokens that the model should generate.

The range of supported thinking budget values depends on the model. https://firebase.google.com/docs/ai-logic/thinking?api=dev#supported-thinking-budget-values To use the default thinking budget or thinking level for a model, set this value to null or omit it. To disable thinking, when supported by the model, set this value to 0. To use dynamic thinking, allowing the model to decide on the thinking budget based on the task, set this value to -1.

Implementation

final int? thinkingBudget;