ThinkingLevel enum

A preset that balances the trade-off between reasoning quality and response speed for a model's "thinking" process.

Note, not all models support every level.

Inheritance
Available extensions

Values

minimal → const ThinkingLevel

Minimal thinking level.

const ThinkingLevel('MINIMAL')
low → const ThinkingLevel

Low thinking level.

const ThinkingLevel('LOW')
medium → const ThinkingLevel

Medium thinking level.

const ThinkingLevel('MEDIUM')
high → const ThinkingLevel

High thinking level.

const ThinkingLevel('HIGH')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ThinkingLevel>
A constant List of the values in this enum, in order of their declaration.