ToolConfig class final

Config for tools to use with model.

Constructors

ToolConfig({FunctionCallingConfig? functionCallingConfig, RetrievalConfig? retrievalConfig})

Properties

functionCallingConfig FunctionCallingConfig?
Config for function calling.
final
hashCode int
The hash code for this object.
no setterinherited
retrievalConfig RetrievalConfig?
Config that specifies information which can be used by tools during inference calls.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to json object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited