domain property
The domain of the original URI from which the content was retrieved.
This field is only populated when using the Vertex AI Gemini API.
Implementation
final String? domain;
The domain of the original URI from which the content was retrieved.
This field is only populated when using the Vertex AI Gemini API.
final String? domain;