ContextWindowCompressionConfig class
Enables context window compression to manage the model's context window.
This mechanism prevents the context from exceeding a given length.
Constructors
- ContextWindowCompressionConfig({int? triggerTokens, SlidingWindow? slidingWindow})
- Creates a ContextWindowCompressionConfig instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- slidingWindow → SlidingWindow?
-
The sliding window compression mechanism.
final
- triggerTokens → int?
-
The number of tokens (before running a turn) that triggers the context
window compression.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited