totalBillableCharacters property
- @Deprecated('Use `totalTokens` instead; Gemini 2.0 series models and newer are always billed by token count.')
final
The number of characters that the model could bill at.
Always non-negative.
Implementation
@Deprecated(
'Use `totalTokens` instead; Gemini 2.0 series models and newer are always billed by token count.',
)
final int? totalBillableCharacters;