ExecutableCodePart class final
A Part that represents the code that is executed by the model.
Constructors
- ExecutableCodePart({required CodeLanguage language, required String code, bool? isThought})
Properties
- code → String
-
The source code to be executed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isThought → bool?
-
finalinherited
- language → CodeLanguage
-
The programming language of the code.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
Convert the Part content to json format.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited