FirebaseAISdkException class final
Exception indicating a stale package version or implementation bug.
This exception indicates a likely problem with the SDK implementation such as an inability to parse a new response format. Resolution paths may include updating to a new version of the SDK, or filing an issue.
- Implemented types
Constructors
- FirebaseAISdkException(String message)
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited