GoingAwayNotice class
A server message indicating that the server will not be able to service the client soon.
- Implemented types
Constructors
- GoingAwayNotice({String? timeLeft})
-
Creates a GoingAwayNotice instance.
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited