GoogleMapsGroundingChunk class final
A grounding chunk sourced from Google Maps.
Constructors
- GoogleMapsGroundingChunk({String? uri, String? title, String? placeId})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeId → String?
-
This Place's resource name, in
places/{place_id}format.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The title of the place.
final
- uri → String?
-
The URI of the place.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited