GroundingChunk class final
Represents a chunk of retrieved data that supports a claim in the model's response.
This is part of the grounding information provided when grounding is enabled.
Constructors
- GroundingChunk({WebGroundingChunk? web, GoogleMapsGroundingChunk? maps})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maps → GoogleMapsGroundingChunk?
-
Contains details if the grounding chunk is from a Google Maps source.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- web → WebGroundingChunk?
-
Contains details if the grounding chunk is from a web source.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited