ImageAspectRatio enum
An aspect ratio for generated images.
Values
- square1x1 → const ImageAspectRatio
-
Square (1:1) aspect ratio.
const ImageAspectRatio('1:1') - portrait9x16 → const ImageAspectRatio
-
Portrait widescreen (9:16) aspect ratio.
const ImageAspectRatio('9:16') - landscape16x9 → const ImageAspectRatio
-
Widescreen (16:9) aspect ratio.
const ImageAspectRatio('16:9') - portrait3x4 → const ImageAspectRatio
-
Portrait full screen (3:4) aspect ratio.
const ImageAspectRatio('3:4') - landscape4x3 → const ImageAspectRatio
-
Fullscreen (4:3) aspect ratio.
const ImageAspectRatio('4:3') - portrait2x3 → const ImageAspectRatio
-
Portrait (2:3) aspect ratio.
const ImageAspectRatio('2:3') - landscape3x2 → const ImageAspectRatio
-
Landscape (3:2) aspect ratio.
const ImageAspectRatio('3:2') - portrait4x5 → const ImageAspectRatio
-
Portrait (4:5) aspect ratio.
const ImageAspectRatio('4:5') - landscape5x4 → const ImageAspectRatio
-
Landscape (5:4) aspect ratio.
const ImageAspectRatio('5:4') - portrait1x4 → const ImageAspectRatio
-
Portrait (1:4) aspect ratio.
const ImageAspectRatio('1:4') - landscape4x1 → const ImageAspectRatio
-
Landscape (4:1) aspect ratio.
const ImageAspectRatio('4:1') - portrait1x8 → const ImageAspectRatio
-
Portrait (1:8) aspect ratio.
const ImageAspectRatio('1:8') - landscape8x1 → const ImageAspectRatio
-
Landscape (8:1) aspect ratio.
const ImageAspectRatio('8:1') - ultrawide21x9 → const ImageAspectRatio
-
Ultrawide (21:9) aspect ratio.
const ImageAspectRatio('21:9')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Convert to json format.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ImageAspectRatio> - A constant List of the values in this enum, in order of their declaration.