ImageConfig class final
Configuration options for generating images with Gemini models.
Constructors
- ImageConfig({ImageAspectRatio? aspectRatio, ImageSize? imageSize})
-
Initializes configuration options for generating images with Gemini.
const
Properties
- aspectRatio → ImageAspectRatio?
-
The aspect ratio of generated images.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageSize → ImageSize?
-
The size of the generated images.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> - Convert to json format.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited