ImagenControlConfig class final
The configuration for the control.
- Annotations
-
- @experimental
- @Deprecated('All Imagen models are deprecated and will shut down as early as June 2026. ' 'As a replacement, you can migrate your apps to use Gemini Image models (the ' '"Nano Banana" models)(https://firebase.google.com/docs/ai-logic/imagen-models-migration).')
Constructors
- ImagenControlConfig({required ImagenControlType controlType, bool? enableComputation, int? superpixelRegionSize, int? superpixelRuler})
Properties
- controlType → ImagenControlType
-
The type of control.
final
- enableComputation → bool?
-
Whether to enable computation.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- superpixelRegionSize → int?
-
The size of the superpixel region.
final
- superpixelRuler → int?
-
The ruler for the superpixel.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Convert the
ImagenReferenceConfigcontent to json format. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited