ImagenControlType enum
The type of control image.
Values
- canny → const ImagenControlType
-
Use edge detection to ensure the new image follow the same outlines.
const ImagenControlType('CONTROL_TYPE_CANNY') - scribble → const ImagenControlType
-
Use enhanced edge detection to ensure the new image follow similar outlines.
const ImagenControlType('CONTROL_TYPE_SCRIBBLE') - faceMesh → const ImagenControlType
-
Use face mesh control to ensure that the new image has the same facial expressions.
const ImagenControlType('CONTROL_TYPE_FACE_MESH') - colorSuperpixel → const ImagenControlType
-
Use color superpixels to ensure that the new image is similar in shape and color to the original.
const ImagenControlType('CONTROL_TYPE_COLOR_SUPERPIXEL')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ImagenControlType> - A constant List of the values in this enum, in order of their declaration.