addWatermark property
Whether to add an invisible watermark to generated images.
Default value for each imagen model can be found in https://cloud.google.com/vertex-ai/generative-ai/docs/model-reference/imagen-api#generate_images
Implementation
final bool? addWatermark;