ImagenImagePlacement class final
The placement of an image.
- Annotations
-
- @experimental
- @Deprecated('All Imagen models are deprecated and will shut down as early as June 2026. ' 'As a replacement, you can migrate your apps to use Gemini Image models (the ' '"Nano Banana" models)(https://firebase.google.com/docs/ai-logic/imagen-models-migration).')
Properties
Methods
-
normalizeToDimensions(
ImagenDimensions original, ImagenDimensions newDim) → ImagenImagePlacement - Normalizes the placement to the given dimensions.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCoordinate(
int x, int y) → ImagenImagePlacement - Creates a placement from a coordinate.
Constants
- bottomCenter → const ImagenImagePlacement
- The bottom center of the image.
- bottomLeft → const ImagenImagePlacement
- The bottom left of the image.
- bottomRight → const ImagenImagePlacement
- The bottom right of the image.
- center → const ImagenImagePlacement
- The center of the image.
- leftCenter → const ImagenImagePlacement
- The left center of the image.
- rightCenter → const ImagenImagePlacement
- The right center of the image.
- topCenter → const ImagenImagePlacement
- The top center of the image.
- topLeft → const ImagenImagePlacement
- The top left of the image.
- topRight → const ImagenImagePlacement
- The top right of the image.