ImagenInlineImage class final
Represents an image stored as a base64-encoded string.
Constructors
- ImagenInlineImage({required Uint8List bytesBase64Encoded, required String mimeType})
-
ImagenInlineImage.fromJson(Map<
String, dynamic> json) -
Factory method to create an ImagenInlineImage from a JSON object.
factory
Properties
- bytesBase64Encoded → Uint8List
-
The data contents in bytes, encoded as base64.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String
-
The MIME type of the image format.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
Convert the
ImagenImagecontent to json format. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited