ImagenRawMask class final
A raw mask.
- Inheritance
-
- Object
- ImagenReferenceImage
- ImagenMaskReference
- ImagenRawMask
- Annotations
-
- @experimental
- @Deprecated('All Imagen models are deprecated and will shut down as early as June 2026. ' 'As a replacement, you can migrate your apps to use Gemini Image models (the ' '"Nano Banana" models)(https://firebase.google.com/docs/ai-logic/imagen-models-migration).')
Constructors
- ImagenRawMask({required ImagenInlineImage mask, double? dilation, int? referenceId})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → ImagenInlineImage?
-
The actual image data of the reference image.
finalinherited
- referenceConfig → ImagenReferenceConfig?
-
A config describing the reference image.
finalinherited
- referenceId → int?
-
The reference ID of the image.
finalinherited
- referenceType → _ReferenceType
-
The type of the reference image.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
{int referenceIdOverrideIfNull = 0}) → Map< String, Object?> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited