ImagenSubjectReferenceType enum
The type of the subject in the image.
- Inheritance
- Available extensions
- Annotations
-
- @experimental
- @Deprecated('All Imagen models are deprecated and will shut down as early as June 2026. ' 'As a replacement, you can migrate your apps to use Gemini Image models (the ' '"Nano Banana" models)(https://firebase.google.com/docs/ai-logic/imagen-models-migration).')
Values
- person → const ImagenSubjectReferenceType
-
The subject is a person.
const ImagenSubjectReferenceType('SUBJECT_TYPE_PERSON') - animal → const ImagenSubjectReferenceType
-
The subject is an animal.
const ImagenSubjectReferenceType('SUBJECT_TYPE_ANIMAL') - product → const ImagenSubjectReferenceType
-
The subject is a product.
const ImagenSubjectReferenceType('SUBJECT_TYPE_PRODUCT')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ImagenSubjectReferenceType> - A constant List of the values in this enum, in order of their declaration.