properties property
Properties of this type if this is a SchemaType.object.
Implementation
@override
Map<String, JSONSchema>? get properties =>
super.properties as Map<String, JSONSchema>?;
Properties of this type if this is a SchemaType.object.
Implementation
@override
set properties(covariant Map<String, JSONSchema>? value) =>
super.properties = value;