LiveServerToolCallCancellation class
A tool call cancellation in a live stream.
Notification for the client that a previously issued ToolCallMessage
with the specified ids should have been not executed and should be
cancelled. If there were side-effects to those tool calls, clients may
attempt to undo the tool calls. This message occurs only in cases where the
clients interrupt server turns.
- Implemented types
Constructors
-
LiveServerToolCallCancellation({List<
String> ? functionIds}) - Creates a LiveServerToolCallCancellation instance.
Properties
-
functionIds
→ List<
String> ? -
The list of FunctionCall.id to cancel.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited