SessionResumptionConfig constructor
SessionResumptionConfig()
Creates a SessionResumptionConfig to start a new resumable session.
When this is included in the session setup, the server will send SessionResumptionUpdate messages with handles that can be used to resume the session later.
Implementation
SessionResumptionConfig() : handle = null;