SessionResumptionUpdate class
An update of the session resumption state.
This message is only sent if SessionResumptionConfig was set in the session setup.
- Implemented types
Constructors
- SessionResumptionUpdate({String? newHandle, bool? resumable, int? lastConsumedClientMessageIndex})
- Creates a SessionResumptionUpdate instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastConsumedClientMessageIndex → int?
-
The index of the last client message that is included in the state
represented by this update.
final
- newHandle → String?
-
The new handle that represents the state that can be resumed. Empty if
resumableis false.final - resumable → bool?
-
Indicates if the session can be resumed at this point.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited