lastConsumedClientMessageIndex property
The index of the last client message that is included in the state represented by this update.
Implementation
final int? lastConsumedClientMessageIndex;
The index of the last client message that is included in the state represented by this update.
final int? lastConsumedClientMessageIndex;