SpeechConfig class
Configures speech synthesis settings.
Allows specifying the desired voice for speech synthesis.
Constructors
- SpeechConfig({String? voiceName})
- Creates a SpeechConfig instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- voiceConfig → VoiceConfig?
-
The voice config to use for speech synthesis.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited