TemplateAutoFunctionDeclaration class final
A function declaration for a template tool that can be called by the model.
- Inheritance
-
- Object
- TemplateFunctionDeclaration
- TemplateAutoFunctionDeclaration
Constructors
Properties
-
callable
→ FutureOr<
Map< Function(Map<String, Object?> >String, Object?> args) -
The callable function that this declaration represents.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasSchema → bool
-
Whether the function declaration has a schema override.
no setterinherited
- name → String
-
The name of the function.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Convert to json object.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited