TemplateChatSession class final
A back-and-forth chat with a server template.
Records messages sent and received in history. The history will always record the content from the first candidate in the GenerateContentResponse, other candidates may be available on the returned response. The history reflects the most current state of the chat session.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendMessage(
Content message) → Future< GenerateContentResponse> -
Sends
messageto the server template as a continuation of the chat history. -
sendMessageStream(
Content message) → Stream< GenerateContentResponse> -
Sends
messageto the server template as a continuation of the chat history. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited