TemplateTool class final
A collection of template tools.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
templateAutoFunctionDeclarations
→ List<
TemplateAutoFunctionDeclaration> -
Returns a list of all TemplateAutoFunctionDeclaration objects
found within the
_functionDeclarationslist.no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object> - Convert to json object.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
functionDeclarations(
List< TemplateFunctionDeclaration> functionDeclarations) → TemplateTool - Returns a TemplateTool instance with list of TemplateFunctionDeclaration.