ThinkingConfig class
Config for thinking features.
Constructors
- ThinkingConfig({int? thinkingBudget, ThinkingLevel? thinkingLevel, bool? includeThoughts})
- Deprecated public constructor of ThinkingConfig.
- ThinkingConfig.withThinkingBudget(int? thinkingBudget, {bool? includeThoughts})
-
Initializes ThinkingConfig with
thinkingBudget.factory - ThinkingConfig.withThinkingLevel(ThinkingLevel? thinkingLevel, {bool? includeThoughts})
-
Initializes ThinkingConfig with
thinkingLevel.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- includeThoughts → bool?
-
Whether to include thoughts in the response.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thinkingBudget → int?
-
The number of thoughts tokens that the model should generate.
final
- thinkingLevel → ThinkingLevel?
-
A preset that controls the model's "thinking" process.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited