googleMaps static method
Creates a tool that allows the model to use Grounding with Google Maps.
Grounding with Google Maps can be used to allow the model to connect to Google Maps to access and incorporate location-based information into its responses.
When using this feature, you are required to comply with the "Grounding with Google Maps" usage requirements for your chosen API provider: Gemini Developer API or Vertex AI Gemini API (see Service Terms section within the Service Specific Terms).
googleMaps: An empty GoogleMaps object.
Returns a Tool configured for Google Maps.
Implementation
static Tool googleMaps({GoogleMaps googleMaps = const GoogleMaps()}) {
return Tool._(null, null, null, null, googleMaps);
}