ToolConfig class final

Config for tools to use with model.

Constructors

ToolConfig({FunctionCallingConfig? functionCallingConfig})

Properties

functionCallingConfig FunctionCallingConfig?
Config for function calling.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
Convert to json object.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited