WebGroundingChunk class final
A grounding chunk sourced from the web.
Constructors
- WebGroundingChunk({String? uri, String? title, String? domain})
Properties
- domain → String?
-
The domain of the original URI from which the content was retrieved.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
The title of the retrieved web page.
final
- uri → String?
-
The URI of the retrieved web page.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited